\name{rareMETALS.gene}
\alias{rareMETALS.gene}
\title{
This function performs meta-analysis for gene-level association test
using RAREMETALS method.
}
\description{
  The function implements the method of RARE-METALS for performing
  gene-level association test. By sharing information on single variant
  score statistics, and their variance-covariance matrix within a
  sliding window, a variety of gene-level association test can be
  constructed centrally, which include simple or weighted burden test, sequence
  kernel association test and variable threshold test.

  The user can determine centrally the rare variant test they want to
  perform, and the set of variants they want to analyze. 
}
\usage{
rareMETALS.gene(ANNO, score.stat.file, cov.file, gene, test = "GRANVIL",
maf.cutoff, no.boot = 10000, alternative = c("two.sided", "greater",
"less"), alpha = 0.05, ix.gold = 1, out.digits = 4, callrate.cutoff = 0, hwe.cutoff = 0, gene.file = "refFlat_hg19.txt.gz")
}
\arguments{
  \item{ANNO}{
    Annotation information for the set of variants to be
    analyzed. Supported types include Nonsynonymous, Stop_Gain,
    Stop_Loss, Essential_Splice_Site, Synonymous. Multiple types of
    variants are also supported, for example, it is possible to use | to
    select multiple variant types, e.g. Nonsynonymous|Stop_Gain|Stop_Loss    
  }
  \item{score.stat.file}{
    Vector of file names of score statistic file. The file needs to be
    bgzip compressed and tabix indexed. 
  }
  \item{cov.file}{Vector of file names of covariance matrix file. The file needs to be
    bgzip compressed and tabix indexed. 
  }
  \item{gene}{Vector of gene names that is to be analyzed. }
  \item{test}{Rare variant test to be performed. Supported options include
  GRANVIL, SKAT, VT. }
  \item{maf.cutoff}{Minor allele frequency cutoff to be used to select variants for
  gene-level test. }
  \item{no.boot}{Number of bootstraps to be performed. }
  \item{alternative}{Alternative hypothesis to be tested. For GRANVIL test, options
    include two.sided, greater and less. For SKAT and VT test, only
    two.sided option is supported.}
  \item{alpha}{Significance threshold. This option is used with no.boot
    parameter. It will determine the number of bootstraps to be performed}
  \item{callrate.cutoff}{The default value is set for callrate is
    0.9. Variant sites with call rate below 0.9 is automatically labeled
    as NA.}
  \item{hwe.cutoff}{The default value for Hardy Weinberg p-value cutoff is 1e-7. Sites
    with extreme HWE p-values are labeled as NA.}
  \item{ix.gold}{Gold standard population. Since there may be
  incompatible allele labels between different studies, it may be
  helpful to specify a gold standard population, with which allele
  labels can be compared and corrected correspondingly.  } 
  \item{out.digits}{Specify output digits for numerical values, such as
  p.values etc.  }
  \item{gene.file}{File name for refFlat table resource file.  }
}
\details{
  
}
\value{
  
}
\references{
  Liu DJ et al Meta-analysis of Gene-level Associations, submitted, 2013
}
\author{
Dajiang J. Liu, Xiaowei Zhan
}
\note{

}
\seealso{

}
\examples{

}
